«MySho»

#### Название товара

# 200р. × 2 шт.

Описание товара Описание товара Описание товара Описание товара Описание товара Описание товара

#### Название товара

# 100р. × 1 шт.

Описание товара Описание товара Описание товара Описание товара Описание товара Описание товара

#### Название товара

# 300р. × 3 шт.

Описание товара Описание товара Описание товара Описание товара Описание товара Описание товара

## Итоговая стоимость: 600р.